Data Collection | Security Lab
Author: Your Name
Description: Keeping your workflows secure.
Date: 2023-10-23T08:48:41-07:00

# Data Collection

As you navigate through the Website, we may also automatically collect details about your visits to the Website, including: your IP address, usage patterns, traffic data, location data, logs, other communication data, and the resources that you access, as well as information about your device and internet connection, including your operating system and browser type.

Additionally, the visitors IP address may also be logged and stored for security purposes by GitHub, regardless of whether the visitor has signed into GitHub or not.

Enter your search term...